@@ -129,7 +129,7 @@ dwg_read_file(const char *restrict filename, Dwg_Data *restrict dwg)
   FILE *fp;
   struct stat attrib;
   size_t size;
-  Bit_Chain bit_chain;
+  Bit_Chain bit_chain = { 0 };
   int error;
 
   loglevel = dwg->opts;
@@ -218,7 +218,7 @@ dxf_read_file(const char *restrict filename, Dwg_Data *restrict dwg)
   FILE *fp;
   struct stat attrib;
   size_t size;
-  Bit_Chain dat;
+  Bit_Chain dat = { 0 };
 
   if (stat(filename, &attrib))
     {
@@ -287,7 +287,7 @@ dxf_read_file(const char *restrict filename, Dwg_Data *restrict dwg)
     error = dwg_read_dxfb(&dat, dwg);
   else
     error = dwg_read_dxf(&dat, dwg);
-  
+
   if (error >= DWG_ERR_CRITICAL)
     {
       LOG_ERROR("Failed to decode DXF file: %s\n", filename)
@@ -310,7 +310,7 @@ dwg_write_file(const char *restrict filename, const Dwg_Data *restrict dwg)
 {
   FILE *fh;
   struct stat attrib;
-  Bit_Chain dat;
+  Bit_Chain dat = { 0 };
   int error;
 
   assert(filename);
@@ -331,7 +331,7 @@ dwg_write_file(const char *restrict filename, const Dwg_Data *restrict dwg)
       }
       return error;
     }
- 
+
   // try opening the output file in write mode
   if (!stat (filename, &attrib))
     {
@@ -365,7 +365,7 @@ dwg_write_file(const char *restrict filename, const Dwg_Data *restrict dwg)
 
   return error;
 }
-#endif /* USE_WRITE */ 
+#endif /* USE_WRITE */
 
 /* THUMBNAIL IMAGE DATA (R13C3+) */
 unsigned char *
@@ -397,7 +397,7 @@ dwg_bmp(const Dwg_Data *restrict dwg, BITCODE_RL *restrict size)
       env_var_checked_p = true;
     }
 #endif  /* USE_TRACING */
-  
+
   osize = bit_read_RL(dat); /* overall size of all images */
   LOG_TRACE("overall size: " FORMAT_RL "\n", osize)
   num_pictures = bit_read_RC(dat);
@@ -745,7 +745,7 @@ get_first_owned_object(const Dwg_Object *hdr)
 
   if (R_13 <= version && version <= R_2000)
     {
-      return _hdr->first_entity->obj;
+      return _hdr->first_entity ? _hdr->first_entity->obj : NULL;
     }
 
   if (version >= R_2004)
@@ -881,6 +881,9 @@ dwg_section_type(const DWGCHAR *wname)
   uint16_t c;
   int i = 0;
 
+  if (wname == NULL)
+    return SECTION_UNKNOWN;
+
   wp = (DWGCHAR *)wname;
   while ((c = *wp++)) {
     name[i++] = (char)(c & 0xff);
