@@ -665,7 +665,7 @@ Dxf_Field* dxf_search_field(Dwg_Object *restrict obj, const char *restrict name,
 }
 
 static int
-dxf_common_entity_handle_data(Bit_Chain *dat, Dwg_Object* obj)
+dxf_common_entity_handle_data(Bit_Chain *restrict dat, Dwg_Object *restrict obj)
 {
   (void)dat; (void)obj;
   return 0;
@@ -677,7 +677,8 @@ dxf_common_entity_handle_data(Bit_Chain *dat, Dwg_Object* obj)
    DWG_ERR_UNHANDLEDCLASS or some other error otherwise
  */
 static int
-dwg_indxf_variable_type(Dwg_Data * dwg, Bit_Chain *dat, Dwg_Object* obj)
+dwg_indxf_variable_type(Dwg_Data *restrict dwg, Bit_Chain *restrict dat,
+                        Dwg_Object *restrict obj)
 {
   int i;
   Dwg_Class *klass;
@@ -859,8 +860,8 @@ dwg_indxf_object(Bit_Chain *restrict dat, Dwg_Object *restrict obj)
       return dwg_indxf_OLEFRAME(dat, obj);
     case DWG_TYPE_VBA_PROJECT:
       LOG_ERROR("Unhandled Object VBA_PROJECT. Has its own section\n");
-      return DWG_ERR_INVALIDTYPE;
       //dwg_indxf_VBA_PROJECT(dat, obj);
+      return DWG_ERR_INVALIDTYPE;
     case DWG_TYPE_LAYOUT:
       return dwg_indxf_LAYOUT(dat, obj);
     case DWG_TYPE_PROXY_ENTITY:
