@@ -1100,7 +1100,7 @@ dxf_format (int code)
     return "%-16.14f";
   if (code < 80)
     return "%6i";
-  if (80 <= code && code <= 99) //BL int32
+  if (80 <= code && code <= 99) //BL int32 lgtm [cpp/constant-comparison]
     return "%9li";
   if (code == 100)
     return "%s";
@@ -1303,7 +1303,7 @@ dxf_tables_write (Bit_Chain *restrict dat, Dwg_Data *restrict dwg)
           }
         ENDTAB();
       }
-  }  
+  }
   {
     Dwg_Object_STYLE_CONTROL *_ctrl = &dwg->style_control;
     Dwg_Object *ctrl = &dwg->object[_ctrl->objid];
@@ -1491,8 +1491,10 @@ dxf_blocks_write (Bit_Chain *restrict dat, Dwg_Data *restrict dwg)
 
   if (psref && psref->obj && psref->obj->tio.object->tio.BLOCK_HEADER->block_entity)
     hdr = psref->obj;
-  else
+  else if (_ctrl->paper_space)
     hdr = _ctrl->paper_space->obj;
+  else
+    hdr = NULL;
 
   if (hdr) {
       obj = get_first_owned_block(hdr);
